==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebRangeSliderValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescription } from "./WebRangeSliderValueDescription";
/**
 * @hidden
 */
export let WebRangeSliderValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRangeSliderValueDescriptionMetadata extends Base {
        static b(a) {
            if (WebRangeSliderValueDescriptionMetadata.a == null) {
                WebRangeSliderValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRangeSliderValueDescriptionMetadata.c(WebRangeSliderValueDescriptionMetadata.a);
            }
            if (a.k(WebRangeSliderValueDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRangeSliderValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RangeSliderValue");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Lower", "Number:double");
            a.item("Upper", "Number:double");
        }
        static d(a) {
            WebRangeSliderValueDescriptionMetadata.b(a);
            a.ad("WebRangeSliderValue", () => new WebRangeSliderValueDescription());
            a.ac("WebRangeSliderValue", WebRangeSliderValueDescriptionMetadata.a);
        }
    }
    WebRangeSliderValueDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRangeSliderValueDescriptionMetadata, 'WebRangeSliderValueDescriptionMetadata');
    WebRangeSliderValueDescriptionMetadata.a = null;
    return WebRangeSliderValueDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebRangeSliderValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescription } from "./WebRangeSliderValueDescription";
/**
 * @hidden
 */
export let WebRangeSliderValueDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRangeSliderValueDescriptionMetadata extends Base {
        static b(a) {
            if (WebRangeSliderValueDescriptionMetadata.a == null) {
                WebRangeSliderValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRangeSliderValueDescriptionMetadata.c(WebRangeSliderValueDescriptionMetadata.a);
            }
            if (a.k(WebRangeSliderValueDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRangeSliderValueDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RangeSliderValue");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Lower", "Number:double");
            a.item("Upper", "Number:double");
        }
        static d(a) {
            WebRangeSliderValueDescriptionMetadata.b(a);
            a.ae("WebRangeSliderValue", () => new WebRangeSliderValueDescription());
            a.ad("WebRangeSliderValue", WebRangeSliderValueDescriptionMetadata.a);
        }
    }
    WebRangeSliderValueDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRangeSliderValueDescriptionMetadata, 'WebRangeSliderValueDescriptionMetadata');
    WebRangeSliderValueDescriptionMetadata.a = null;
    return WebRangeSliderValueDescriptionMetadata;
})();
